UltraJSON with Gentoo patches
=============================

UltraJSON fork with `Gentoo patches`_ applied.

.. _Gentoo patches: https://gitweb.gentoo.org/repo/gentoo.git/tree/dev-python/ujson/files

To install it just run Pip as usual:

.. code-block:: sh

    $ pip install ujsongp
